@@ -95,6 +95,7 @@ class CodigoErrorAcuseServidor(str, Enum):
     folio_paquete_original_invalido = 'ET02'
     tipo_pago_obligatorio = 'EV01'
     tipo_pago_invalido = 'EV02'
+    tipo_pago_no_catalogado = 'EV03'
     clasificacion_operacion_obligatoria = 'EW01'
     clasificacion_operacion_maximo_2_digitos = 'EW02'
 
@@ -126,3 +127,4 @@ class CodigoErrorAcuseBanxico(str, Enum):
     cda_duplicada = '54'
     monto_cda_incorrecto = '55'
     tipo_pago_incorrecto = '56'
+    fecha_calendario_incorrecta = '57'
