@@ -13,7 +13,7 @@ class OrdenPagoElement(object):
 class MensajeElement(object):
     def __new__(cls, ordenpago):
         return etree.fromstring(  # noqa: S320
-            bytes(ordenpago.text, encoding='cp850'),
+            bytes(ordenpago.text.strip(), encoding='cp850'),
         )
 
 
@@ -32,6 +32,6 @@ class BodyElement(object):
 class OrdenResponse(object):
     def __new__(cls, orden):
         mensaje = etree.fromstring(  # noqa: S320
-            bytes(orden, encoding='utf-8'),
+            bytes(orden, encoding='cp850'),
         )
         return OrdenPagoElement(MensajeElement(RootElement(BodyElement(mensaje))))
